@@ -107,14 +107,21 @@ class ClusteringOptimizer:
 			return self._inertias.copy()
 		elif by.startswith('distortion'):
 			return self._distortions.copy()
+		else:
+			raise ValueError(f'Unsupported scoring method: "{by}"')
 
 	def plot(self, by='silhouette_score', size=(16, 8)):
 		scores = self.get_scores(by=by)
+		if by.startswith('silhouette'):
+			title = 'Finding the Optimal k with the Silhouette Method'
+		else:
+			title = 'Finding the Optimal k with the Elbow Method'
+
 		plt.figure(figsize=size)
 		plt.plot(list(scores.keys()), list(scores.values()), 'bx-')
 		plt.xlabel('k')
 		plt.ylabel(by.replace('_', ' ').capitalize())
-		plt.title('The Elbow Method showing the optimal k')
+		plt.title(title)
 		plt.show()
 
 	def get_optimal_number_of_clusters(self, by='silhouette'):
